MODULE earth_const
  USE prec
  USE math_const
  
  REAL(rstd),SAVE :: radius=6.37122E6
  REAL(rstd),SAVE :: g=9.80616
  REAL(rstd),PARAMETER :: daysec=86400
  REAL(rstd),SAVE :: omega=7.292E-5
  REAL(rstd),SAVE :: kappa=0.2857143
  REAL(rstd),SAVE :: cpp=1004.70885
  REAL(rstd),SAVE :: preff=101325.
  REAL(rstd),SAVE :: pa=50000.
  REAL(rstd),SAVE :: scale_height=8000. ! atmospheric scale height (m)
  REAL(rstd),SAVE :: scale_factor=1.
  REAL(rstd),SAVE :: gas_constant = 8.3144621 
  REAL(rstd),SAVE :: mu                 ! molar mass of the atmosphere

  LOGICAL, SAVE :: boussinesq, hydrostatic
  !$OMP THREADPRIVATE(boussinesq, hydrostatic)

CONTAINS
  
  SUBROUTINE init_earth_const
  USE getin_mod
  IMPLICIT NONE
  REAL(rstd) :: X=1
  
    CALL getin("radius",radius)
    CALL getin("g",g)
    CALL getin("scale_factor",scale_factor)
    CALL getin("omega",omega)  
    CALL getin("kappa",kappa)  
    CALL getin("cpp",cpp)  
    CALL getin("preff",preff)  
    CALL getin("scale_height",scale_height)
    
    boussinesq=.FALSE.
    CALL getin("boussinesq",boussinesq)  
    hydrostatic=.TRUE.
    CALL getin("hydrostatic",hydrostatic)  
    IF(boussinesq .AND. .NOT. hydrostatic) THEN
       PRINT *, 'boussinesq=.TRUE. and hydrostatic=.FALSE. : Non-hydrostatic boussinesq equations are not supported'
       STOP
    END IF
    
    mu=kappa/cpp
    radius=radius/scale_factor
    omega=omega*scale_factor
    
  END SUBROUTINE init_earth_const
  
  
END MODULE earth_const
